Documentation
¶
Index ¶
- Variables
- type Automaton
- type CollectionStats
- type Data
- type DataReader
- type Dictionary
- type DictionaryEntry
- type DictionaryIterator
- type DictionaryLookup
- type DocVisitState
- type Document
- type DocumentValueReader
- type DocumentValueVisitor
- type Field
- type FieldTerm
- type Impact
- type ImpactPostingsIterator
- type Location
- type Merger
- type Optimizable
- type OptimizableContext
- type OptimizablePostingsIterator
- type Posting
- type PostingsIterator
- type PostingsList
- type Segment
- type StoredFieldVisitor
- type Term
- type TermStats
- type VisitField
- type VisitLocation
- type VisitTerm
Constants ¶
This section is empty.
Variables ¶
var ErrClosed = fmt.Errorf("index closed")
Functions ¶
This section is empty.
Types ¶
type Automaton ¶
type Automaton interface {
// Start returns the start state.
Start() int
// IsMatch returns true if and only if the state is a match.
IsMatch(int) bool
// CanMatch returns true if and only if it is possible to reach a match
// in zero or more steps.
CanMatch(int) bool
// WillAlwaysMatch returns true if and only if the current state matches
// and will always match no matter what steps are taken.
WillAlwaysMatch(int) bool
// Accept returns the next state given the input to the specified state.
Accept(int, byte) int
}
type CollectionStats ¶
type CollectionStats interface {
TotalDocumentCount() uint64
DocumentCount() uint64
SumTotalTermFrequency() uint64
Merge(CollectionStats)
}
type Data ¶
type Data struct {
// contains filtered or unexported fields
}
Data is an opaque representation of data backed by memory or a ReaderAt.
func NewDataBytes ¶
func (*Data) Reader ¶
func (d *Data) Reader() *DataReader
type DataReader ¶
type DataReader struct {
// contains filtered or unexported fields
}
type Dictionary ¶
type Dictionary interface {
DictionaryLookup
PostingsList(term []byte, except *roaring.Bitmap, prealloc PostingsList) (PostingsList, error)
Iterator(a Automaton, startKeyInclusive, endKeyExclusive []byte) DictionaryIterator
}
type DictionaryEntry ¶
type DictionaryIterator ¶
type DictionaryIterator interface {
Next() (DictionaryEntry, error)
Close() error
}
type DictionaryLookup ¶
type DocVisitState ¶
type DocVisitState interface{}
type Document ¶
type Document interface {
Analyze()
EachField(vf VisitField)
}
type DocumentValueReader ¶
type DocumentValueReader interface {
VisitDocumentValues(number uint64, visitor DocumentValueVisitor) error
}
type DocumentValueVisitor ¶
type FieldTerm ¶
type FieldTerm interface {
Term() []byte
Frequency() int
EachLocation(vl VisitLocation)
}
type Impact ¶
Impact is one non-dominated frequency and raw-norm pair from a postings block. Scorers use the pairs to compute an exact upper bound for the block.
type ImpactPostingsIterator ¶
type ImpactPostingsIterator interface {
HasImpacts() bool
AdvanceShallow(docNum uint64) (blockEnd uint64, impacts []Impact, ok bool, err error)
}
ImpactPostingsIterator is optionally implemented by postings iterators that carry block-level impacts. AdvanceShallow moves only the impact cursor and returns the inclusive end document for the block containing docNum.
type Optimizable ¶
type Optimizable interface {
Optimize(kind string, octx OptimizableContext) (OptimizableContext, error)
}
type OptimizableContext ¶
type OptimizableContext interface {
Finish() (PostingsIterator, error)
}
type PostingsIterator ¶
type PostingsList ¶
type PostingsList interface {
Iterator(includeFreq, includeNorm, includeLocations bool, prealloc PostingsIterator) (PostingsIterator, error)
Size() int
Count() uint64
}
type Segment ¶
type Segment interface {
Dictionary(field string) (Dictionary, error)
VisitStoredFields(num uint64, visitor StoredFieldVisitor) error
Count() uint64
DocsMatchingTerms([]Term) (*roaring.Bitmap, error)
Fields() []string
CollectionStats(field string) (CollectionStats, error)
Size() int
DocumentValueReader(fields []string) (DocumentValueReader, error)
WriteTo(w io.Writer, closeCh chan struct{}) (int64, error)
Type() string
Version() uint32
}
type StoredFieldVisitor ¶
type VisitField ¶
type VisitField func(Field)
type VisitLocation ¶
type VisitLocation func(Location)
Click to show internal directories.
Click to hide internal directories.